#!/bin/bash

# this utility is to compare the current build settings with the one from mainstream

COMMAND=$(basename $0)

REF=$HOME/git/build

function usage () {
    echo "Usage: $COMMAND update|body|tags"
    echo "update: performs svn up on the mainstream build dir"
    echo "body: compares the .mk file"
    echo "tags: compares the tags (from lxc-tags.mk)"
    exit 1
}

function update () {
    echo "Updating $REF"
    (cd $REF ; git pull)
    echo "Update done"
}

function check_body () {
    a=$REF/lxc.mk
    b=wexlxc.mk
    echo "Checking body $a $b"
    diff -w $a $b | egrep -v '^(<|>)( #| +$)|nozomi|comgt|planetlab-umts-tools|boost|gnuradio|bbn|crunchxml|spectools|sge|iwlwifi|kernelconfig=planetlab|umts|DistributedRateLimiting'
}

function check_tags () {
    a=$REF/lxc-tags.mk
    b=wextoolbox-tags.mk
    sed -e s,onelab.eu,planet-lab.org,g $b > $b.norm
    echo "Checking tags $a $b"
    diff -w $REF/lxc-tags.mk $b.norm | egrep -v '^(<|>) #|SVNBRANCH|nozomi|comgt|planetlab-umts-tools|boost|gnuradio|bbn_80211|crunchxml|spectools|ejabberd|omf|DistributedRateLimiting|openvswitch|sfa-|sface-|^[0-9,c]*$|^---$'
}

[[ -z "$@" ]] && usage

for arg in "$@" ; do
    case $arg in
	up*) update ;;
	bo*) check_body ;;
	ta*) check_tags ;;
	*) usage;;
    esac
done
